/*
Copyright 2022 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	scheme "github.com/openkruise/kruise-rollout-api/client/clientset/versioned/scheme"
	v1alpha1 "github.com/openkruise/kruise-rollout-api/rollouts/v1alpha1"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// RolloutHistoriesGetter has a method to return a RolloutHistoryInterface.
// A group's client should implement this interface.
type RolloutHistoriesGetter interface {
	RolloutHistories(namespace string) RolloutHistoryInterface
}

// RolloutHistoryInterface has methods to work with RolloutHistory resources.
type RolloutHistoryInterface interface {
	Create(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.CreateOptions) (*v1alpha1.RolloutHistory, error)
	Update(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.UpdateOptions) (*v1alpha1.RolloutHistory, error)
	UpdateStatus(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.UpdateOptions) (*v1alpha1.RolloutHistory, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.RolloutHistory, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.RolloutHistoryList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.RolloutHistory, err error)
	RolloutHistoryExpansion
}

// rolloutHistories implements RolloutHistoryInterface
type rolloutHistories struct {
	client rest.Interface
	ns     string
}

// newRolloutHistories returns a RolloutHistories
func newRolloutHistories(c *RolloutsV1alpha1Client, namespace string) *rolloutHistories {
	return &rolloutHistories{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the rolloutHistory, and returns the corresponding rolloutHistory object, and an error if there is any.
func (c *rolloutHistories) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.RolloutHistory, err error) {
	result = &v1alpha1.RolloutHistory{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("rollouthistories").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of RolloutHistories that match those selectors.
func (c *rolloutHistories) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.RolloutHistoryList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.RolloutHistoryList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("rollouthistories").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested rolloutHistories.
func (c *rolloutHistories) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("rollouthistories").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a rolloutHistory and creates it.  Returns the server's representation of the rolloutHistory, and an error, if there is any.
func (c *rolloutHistories) Create(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.CreateOptions) (result *v1alpha1.RolloutHistory, err error) {
	result = &v1alpha1.RolloutHistory{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("rollouthistories").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(rolloutHistory).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a rolloutHistory and updates it. Returns the server's representation of the rolloutHistory, and an error, if there is any.
func (c *rolloutHistories) Update(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.UpdateOptions) (result *v1alpha1.RolloutHistory, err error) {
	result = &v1alpha1.RolloutHistory{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("rollouthistories").
		Name(rolloutHistory.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(rolloutHistory).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *rolloutHistories) UpdateStatus(ctx context.Context, rolloutHistory *v1alpha1.RolloutHistory, opts v1.UpdateOptions) (result *v1alpha1.RolloutHistory, err error) {
	result = &v1alpha1.RolloutHistory{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("rollouthistories").
		Name(rolloutHistory.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(rolloutHistory).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the rolloutHistory and deletes it. Returns an error if one occurs.
func (c *rolloutHistories) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("rollouthistories").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *rolloutHistories) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("rollouthistories").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched rolloutHistory.
func (c *rolloutHistories) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.RolloutHistory, err error) {
	result = &v1alpha1.RolloutHistory{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("rollouthistories").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
